@@ -39,20 +39,32 @@ extern "C" {
 #define MAXPATHLEN 1024
 #endif
 
-#define EXIF_JPEG_MARKER   JPEG_APP0+1
+#define JFIF_JPEG_MARKER  JPEG_APP0
+#define JFIF_IDENT_STRING "JFIF\0"
+#define JFIF_IDENT_STRING_SIZE 5
+
+#define JFXX_JPEG_MARKER  JPEG_APP0
+#define JFXX_IDENT_STRING "JFXX\0"
+#define JFXX_IDENT_STRING_SIZE 5
+
+#define EXIF_JPEG_MARKER   JPEG_APP0 + 1
 #define EXIF_IDENT_STRING  "Exif\000\000"
 #define EXIF_IDENT_STRING_SIZE 6
 
-#define IPTC_JPEG_MARKER   JPEG_APP0+13
+#define IPTC_JPEG_MARKER   JPEG_APP0 + 13
 
-#define ICC_JPEG_MARKER   JPEG_APP0+2
+#define ICC_JPEG_MARKER   JPEG_APP0 + 2
 #define ICC_IDENT_STRING  "ICC_PROFILE\0"
 #define ICC_IDENT_STRING_SIZE 12
 
-#define XMP_JPEG_MARKER   JPEG_APP0+1
+#define XMP_JPEG_MARKER   JPEG_APP0 + 1
 #define XMP_IDENT_STRING  "http://ns.adobe.com/xap/1.0/\000"
 #define XMP_IDENT_STRING_SIZE 29
 
+#define ADOBE_JPEG_MARKER JPEG_APP0 + 14
+#define ADOBE_IDENT_STRING "Adobe"
+#define ADOBE_IDENT_STRING_SIZE 5
+
 
 #define PROGRAMNAME "jpegoptim"
 
@@ -75,7 +87,13 @@ void warn(const char *format, ...);
 
 
 /* jpegdest.c */
-void jpeg_memory_dest (j_compress_ptr cinfo, unsigned char **bufptr, size_t *bufsizeptr, size_t incsize);
+void jpeg_memory_dest (j_compress_ptr cinfo, unsigned char **bufptr,
+		size_t *bufsizeptr, size_t incsize);
+
+/* jpegsrc.c */
+void jpeg_custom_src(j_decompress_ptr dinfo, FILE *infile,
+		unsigned char **bufptr,	size_t *bufsizeptr, size_t *bufusedptr, size_t incsize);
+
 
 
 
